Learn R Programming

stlnpp (version 0.3.5)

as.stlpp.lpp: Methods for space-time point patterns on a linear network.

Description

This function projects an object of class stlpp to a linear network.

Usage

as.stlpp.lpp(X)

Arguments

X

an object of class stlpp

Value

An object of class lpp.

Details

This function projects the space-time point pattern x on linear network L into L, giving its corresponding spatial point pattern.

See Also

as.stlpp, lpp, as.lpp

Examples

Run this code
# NOT RUN {
data(easynet)
x <- runifpointOnLines(40, easynet)
t1 <- sample(1:10,40,replace=TRUE)
Y <- as.stlpp(x,t=t1,L=easynet)
as.stlpp.lpp(Y)
# }

Run the code above in your browser using DataLab