Learn R Programming

stlnpp (version 0.3.6)

as.tpp.stlpp: Methods for space-time point patterns on a linear network.

Description

This function converts an object of class stlpp to class tpp.

Usage

# S3 method for stlpp
as.tpp(X)

Arguments

X

an object of class stlpp

Value

An object of class tpp.

Details

This function projects the space-time point pattern X on L times T into the time interval T.

See Also

as.stlpp, lpp, as.lpp

Examples

Run this code
# NOT RUN {
X <- rpoistlpp(10,1,2,easynet)
as.tpp.stlpp(X)
# }

Run the code above in your browser using DataLab