Learn R Programming

stlnpp (version 0.3.5)

density.stlpp: Kernel estimation of intensity of space-time point patterns on a linear network

Description

Kernel density estimation of a spatio-temporal point pattern on a linear network.

Usage

# S3 method for stlpp
density(x,lbw,tbw,at=c("points","pixels"),dimt=512,...)

Arguments

x

an object of class stlpp

lbw

netwrok smoothing bandwidth

tbw

time smoothing bandwidth

at

string specifying whether to compute the intensity values at a grid of pixel locations and time (at="pixels") or only at the points of x (at="points"). default is to estimate the intensity at pixels

dimt

the number of equally spaced points at which the temporal density is to be estimated. see density

...

arguments passed to density.lpp

Value

if at="points": a vector of intensity values at the data points of x.

if at="pixels": a list of images on linear network. Each image represents an estimated saptio-temporal intensity at a fixed time. check the attributes for more accommodated outputs.

Details

Kernel smoothing is applied to the spatio-temporal point pattern x using methods in Moradi et al (2019). If lbw and tbw are not given, then they will be selected using bw.nrd0 and bw.scott.iso respectively.

References

Moradi, M.M. and Mateu, J. (2019). First and second-order characteristics of spatio-temporal point processes on linear networks. Journal of Computational and Graphical Statistics. In press.

See Also

density, density.lpp, bw.nrd0, bw.scott.iso

Examples

Run this code
# NOT RUN {
X <- rpoistlpp(.2,a=0,b=5,L=easynet)
density(X)
# }

Run the code above in your browser using DataLab