fraction (between 0 and 1 inclusive) of the data points that will be used to build a tessellation for the intensity estimate
nrep
number of independent repetitions of the randomised procedure
at
string specifying whether to return the intensity values at a grid of pixel locations and time (at="pixels") or only at the points of X (at="points"). default is to estimate the intensity at pixels
dimt
the number of equally spaced points at which the temporal density is to be estimated. see density
If at="points": a vector of intensity values at the data points of X.
If at="pixels": a vector of intensity values over a grid.
Details
This function computes intensity estimates for temporal point patterns using Voronoi-Dirichlet tessellation.
References
Mateu, J., Moradi, M., & Cronie, O. (2019). Spatio-temporal point patterns on linear networks: Pseudo-separable intensity estimation. Spatial Statistics, 100400.