powered by
Methods for temporal point patterns.
# S3 method for tpp plot(x,xlab="time",ylab="",main = "cumulative number",...) # S3 method for tppint plot(x,xlab=xlab,xlim=xlim,line=2.5,...) # S3 method for tpp print(x,...) # S3 method for tppint print(x,...)
an object of class tpp or tppint.
the x,y label of the plot.
overall title for the plot.
giving the x limits for the plot.
specifying a value for line overrides the default placement of y label, and places it this many lines outwards from the plot edge.
graphics parameters passed to plot/print function.
# NOT RUN { X <- tpp(sample(c(1:24),200,replace = TRUE)) plot(X) plot(density(X)) # }
Run the code above in your browser using DataLab