powered by
This function applies independent random thinning to a spatio-temporal point pattern on a linear network.
# S3 method for stlpp rthin(X, P = P, nsim = 1)
An object of the same kind as X if nsim=1, or a list of such objects if nsim > 1.
a spatio-temporal point pattern of class stlpp
stlpp
retention probability
number of simulated realisations to be generated
Mehdi Moradi <[email protected]>
See rthin.
rthin
Moradi, M., & Mateu, J. (2020). First-and second-order characteristics of spatio-temporal point processes on linear networks. Journal of Computational and Graphical Statistics, 29(3), 432-443.
stlpp, rthin
data(Medellin) rthin(Medellin,P=.5)
Run the code above in your browser using DataLab