powered by
Create spatio-temporal point pattern on linear network.
stlpp(X, L, T, ...)
Locations of the points. A matrix or data frame of coordinates, or a point pattern object (of class "ppp") or other data acceptable to as.ppp or lpp
as.ppp
lpp
linear network (object of class "linnet"). No need to be given if X is an object of lpp
time vector
ignored
an object of class stlpp.
This function creates an object of class stlpp. For details about X see lpp. T represents the time occurrence of data points.
as.stlpp, lpp
as.stlpp
# NOT RUN { X <- rpoislpp(1,easynet) t <- runif(npoints(X)) stlpp(X,T=t,L=easynet) # }
Run the code above in your browser using DataLab