powered by
This function projects an object of class stlpp to a linear network.
stlpp
as.stlpp.lpp(X)
an object of class stlpp
An object of class lpp.
lpp
This function projects the space-time point pattern x on linear network L into L, giving its corresponding spatial point pattern.
as.stlpp, lpp, as.lpp
as.stlpp
as.lpp
# NOT RUN { data(easynet) x <- runifpointOnLines(40, easynet) t1 <- sample(1:10,40,replace=TRUE) Y <- as.stlpp(x,t=t1,L=easynet) as.stlpp.lpp(Y) # }
Run the code above in your browser using DataLab