powered by
This function converts an object of class stlpp to class tpp.
stlpp
tpp
# S3 method for stlpp as.tpp(X)
an object of class stlpp
An object of class tpp.
This function projects the space-time point pattern X on L times T into the time interval T.
as.stlpp, lpp, as.lpp
as.stlpp
lpp
as.lpp
# NOT RUN { X <- rpoistlpp(10,1,2,easynet) as.tpp.stlpp(X) # }
Run the code above in your browser using DataLab