Learn R Programming

stlnpp (version 0.3.6)

rthin.stlpp: Random thinning

Description

Applies independent random thinning to a spatio-temporal point pattern on a linear network.

Usage

# S3 method for stlpp
rthin(X, P = P, nsim = 1)

Arguments

X

a spatio-temporal point pattern of class stlpp

P

retention probability

nsim

number of simulated realisations to be generated

Value

An object of the same kind as X if nsim=1, or a list of such objects if nsim > 1.

Details

See rthin.

See Also

stlpp, rthin

Examples

Run this code
# NOT RUN {
data(Medellin)
rthin(Medellin,P=.5)
# }

Run the code above in your browser using DataLab