powered by
Applies independent random thinning to a spatio-temporal point pattern on a linear network.
# S3 method for stlpp rthin(X, P = P, nsim = 1)
a spatio-temporal point pattern of class stlpp
stlpp
retention probability
number of simulated realisations to be generated
An object of the same kind as X if nsim=1, or a list of such objects if nsim > 1.
See rthin.
rthin
stlpp, rthin
# NOT RUN { data(Medellin) rthin(Medellin,P=.5) # }
Run the code above in your browser using DataLab